package org.example.jasypt.util;


import org.jasypt.encryption.pbe.PooledPBEStringEncryptor;
import org.jasypt.encryption.pbe.config.SimpleStringPBEConfig;

import java.util.Scanner;


public class CyENCUtil {


    /**
     * jasypt-1.9.3 加解密工具类( jasypt-spring-boot-starter 是 2.1.2 )
     */

    private static final String PBEWITHHMACSHA512ANDAES_128 = "PBEWithHmacSHA512AndAES_128";


    /**
     * Jasyp3.x 加密（PBEWITHHMACSHA512ANDAES_256）
     * @param		 plainText  待加密的原文
     * @param		 factor     加密秘钥
     * @return       java.lang.String
     */
    public static String encryptWithSHA512(String plainText, String factor) {
        // 1. 创建加解密工具实例
        PooledPBEStringEncryptor encryptor = new PooledPBEStringEncryptor();
        // 2. 加解密配置
        SimpleStringPBEConfig config = new SimpleStringPBEConfig();
        config.setPassword(factor);
        config.setAlgorithm(PBEWITHHMACSHA512ANDAES_128);
        // 为减少配置文件的书写，以下都是 Jasyp 3.x 版本，配置文件默认配置
        config.setKeyObtentionIterations( "1000");
        config.setPoolSize("1");
        config.setProviderName("SunJCE");
        config.setSaltGeneratorClassName("org.jasypt.salt.RandomSaltGenerator");
        config.setIvGeneratorClassName("org.jasypt.iv.RandomIvGenerator");
        config.setStringOutputType("base64");
        encryptor.setConfig(config);
        // 3. 加密
        return encryptor.encrypt(plainText);
    }

    /**
     * Jaspy3.x 解密（PBEWITHHMACSHA512ANDAES_256）
     * @param		 encryptedText  待解密密文
     * @param		 factor         解密秘钥
     * @return       java.lang.String
     */
    public static String decryptWithSHA512(String encryptedText, String factor) {
        // 1. 创建加解密工具实例
        PooledPBEStringEncryptor encryptor = new PooledPBEStringEncryptor();
        // 2. 加解密配置
        SimpleStringPBEConfig config = new SimpleStringPBEConfig();
        config.setPassword(factor);
        config.setAlgorithm(PBEWITHHMACSHA512ANDAES_128);
        // 为减少配置文件的书写，以下都是 Jasyp 3.x 版本，配置文件默认配置
        config.setKeyObtentionIterations("1000");
        config.setPoolSize("1");
        config.setProviderName("SunJCE");
        config.setSaltGeneratorClassName("org.jasypt.salt.RandomSaltGenerator");
        config.setIvGeneratorClassName("org.jasypt.iv.RandomIvGenerator");
        config.setStringOutputType("base64");
        encryptor.setConfig(config);
        // 3. 解密
        return encryptor.decrypt(encryptedText);
    }




    public static void main(String[] args) {
        //加密因子
        String salt = "nfei7ur67nfg345srj34HDbvdn";
        //窗口提示输入字符串
        System.out.println("请输入待加密字符串：");
        String plainText = new Scanner(System.in).nextLine();
        //这个每次跑的结果不一样
        String encryptWithMD5Str = encryptWithSHA512(plainText, salt);
        //虽然不一样，这个也能正常执行
        String decryptWithMD5Str = decryptWithSHA512(encryptWithMD5Str, salt);

        System.out.println("加密前："+plainText);
        System.out.println("加密后："+encryptWithMD5Str);
        System.out.println("解密后："+decryptWithMD5Str);
        System.out.println("使用方式：将生成的加密字符串用ENC()包装放入配置文件即可");
        System.out.println("例如：password: ENC("+encryptWithMD5Str+")");
        System.out.println("======================================================================================");
        main(args);
    }

}

